@@ -127,7 +127,7 @@ prettySeq <- function(x) paste("Resample", gsub(" ", "0", format(seq(along = x))
 
 ipredStats <- function(x)
 {
-  requireNamespace("e1071", quietly = TRUE)
+  requireNamespaceQuietStop("e1071")
   ## error check
   if(is.null(x$X)) stop("to get OOB stats, keepX must be TRUE when calling the bagging function")
   
@@ -136,15 +136,15 @@ ipredStats <- function(x)
       holdY <- y[-object$bindx]
       if(is.factor(y))
         {
-          requireNamespace("e1071", quietly = TRUE)
-          tmp <- predict(object$btree, x[-object$bindx,], type = "class")
+          requireNamespaceQuietStop("e1071")
+          tmp <- predict(object$btree, x[-object$bindx,,drop = FALSE], type = "class")
           tmp <- factor(as.character(tmp), levels = levels(y))
           out <- c(
                    mean(holdY == tmp),
                    e1071::classAgreement(table(holdY, tmp))$kappa)
           
         } else {
-          tmp <- predict(object$btree, x[-object$bindx,])
+          tmp <- predict(object$btree, x[-object$bindx,,drop = FALSE])
 
           out <- c(
                    sqrt(mean((tmp - holdY)^2, na.rm = TRUE)),
@@ -167,7 +167,7 @@ rfStats <- function(x)
                 x$type,
                 regression =   c(sqrt(max(x$mse[length(x$mse)], 0)), x$rsq[length(x$rsq)]),
                 classification = {
-                  requireNamespace("e1071", quietly = TRUE)
+                  requireNamespaceQuietStop("e1071")
                   c(
                     1 - x$err.rate[x$ntree, "OOB"],
                     e1071::classAgreement(x$confusion[,-dim(x$confusion)[2]])[["kappa"]])
@@ -201,27 +201,6 @@ R2 <- function(pred, obs, formula = "corr", na.rm = FALSE)
 
 RMSE <- function(pred, obs, na.rm = FALSE) sqrt(mean((pred - obs)^2, na.rm = na.rm))
 
-
-defaultSummary <- function(data, lev = NULL, model = NULL)
-  {
-    if(is.character(data$obs)) data$obs <- factor(data$obs, levels = lev)
-    postResample(data[,"pred"], data[,"obs"])
-  }
-
-twoClassSummary <- function (data, lev = NULL, model = NULL) 
-{
-  require(pROC)
-  if (!all(levels(data[, "pred"]) == levels(data[, "obs"]))) 
-    stop("levels of observed and predicted data do not match")
-  rocObject <- try(pROC::roc(data$obs, data[, lev[1]]), silent = TRUE)
-  rocAUC <- if(class(rocObject)[1] == "try-error") NA else rocObject$auc
-  out <- c(rocAUC,
-           sensitivity(data[, "pred"], data[, "obs"], lev[1]),
-           specificity(data[, "pred"], data[, "obs"], lev[2]))
-  names(out) <- c("ROC", "Sens", "Spec")
-  out
-}
-
 partRuleSummary <- function(x)
   {
     predictors <- all.vars(x$terms)
@@ -361,3 +340,53 @@ scrubCall <- function(x)
     for(i in items) if(nchar(as.character(x[i])) > 100) x[i] <- "scrubbed"
     x
   }
+
+class2ind <- function(x, drop2nd = FALSE) {
+	if(!is.factor(x)) stop("'x' should be a factor")
+	y <- model.matrix(~ x - 1) 
+	colnames(y) <- gsub("^x", "", colnames(y))
+	attributes(y)$assign <- NULL
+	attributes(y)$contrasts <- NULL
+	if(length(levels(x)) == 2 & drop2nd) {
+		y <- y[,1]
+	}
+	y
+}
+
+requireNamespaceQuietStop <- function(package) {
+    if (!requireNamespace(package, quietly = TRUE))
+        stop(paste('package',package,'is required'))
+}
+
+get_resample_perf <- function (x, ...) UseMethod("get_resample_perf")
+
+get_resample_perf.train <- function(x) {
+  if(x$control$returnResamp == "none")
+    stop("use returnResamp == 'none' in trainControl()")
+  out <- merge(x$resample, x$bestTune)
+  out[, c(x$perfNames, "Resample")]
+}
+
+get_resample_perf.rfe <- function(x) {
+  if(x$control$returnResamp == "none")
+    stop("use returnResamp == 'none' in trainControl()")
+  out <- subset(x$resample, Variables == x$bestSubset) 
+  out[, c(x$perfNames, "Resample")]
+}
+
+get_resample_perf.sbf <- function(x) {
+  if(x$control$returnResamp == "none")
+    stop("use returnResamp == 'none' in trainControl()")
+  x$resample
+}
+
+get_resample_perf.safs <- function(x) {
+  out <- subset(x$external, Iter == x$optIter)
+  out[, !(names(out) %in% "Iter")]
+}
+
+get_resample_perf.gafs <- function(x) {
+  out <- subset(x$external, Iter == x$optIter)
+  out[, !(names(out) %in% "Iter")]
+}
+
